pub struct MerkleProof {
pub leaf_index: usize,
pub leaf_count: usize,
pub siblings: Vec<MtHash>,
}Fields
leaf_index: usizeIndex of the leaf being proven
leaf_count: usizeTotal number of leaves in the tree
siblings: Vec<MtHash>The path of sibling chaining values (bottom-up order).
Implementations
Sourceimpl MerkleProof
impl MerkleProof
pub fn new(leaf_index: usize, leaf_count: usize, siblings: Vec<MtHash>) -> Self
Sourcepub fn verify<S>(
&self,
root: &MtHash,
column_values: &[S],
leaf_index: usize,
) -> Result<(), MerkleError>where
S: ConstTranscribable,
pub fn verify<S>(
&self,
root: &MtHash,
column_values: &[S],
leaf_index: usize,
) -> Result<(), MerkleError>where
S: ConstTranscribable,
Verifies the proof against a known root hash and the claimed element data.
Sourcepub fn estimate_transcribed_size(merkle_tree_height: usize) -> usize
pub fn estimate_transcribed_size(merkle_tree_height: usize) -> usize
Estimate the number of bytes that would be written to [[PcsTranscript]] when an instance of this type is transcribed.